@@ -223,7 +223,7 @@ my $term  = $input;
 my @c = ();
 if($input=~/C[0-9]+/) {
     push @c, $input;
-    ($term) = $umls->getTermList($input);
+    ($term) = $umls->getAllPreferredTerm($input);
 }
 else {
     @c = $umls->getConceptList($input);
@@ -310,7 +310,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getParents.pl,v 1.10 2010/05/24 17:57:16 btmcinnes Exp $';
+    print '$Id: getParents.pl,v 1.11 2010/09/17 18:54:31 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
